=====
Aetos
=====

.. image:: https://governance.openstack.org/tc/badges/aetos.svg

.. Change things from this point on

--------
Overview
--------
Aetos is a reverse-proxy for enforcing openstack multi-tenancy for Prometheus.

Aetos is a reverse-proxy, which when placed in front of Prometheus will
enforce openstack multi-tenancy and keystone authentication for every
Prometheus query.

Aetos is distributed under the terms of the Apache
License, Version 2.0. The full terms and conditions of this
license are detailed in the LICENSE file.

-------------
Documentation
-------------

Release notes are available at
https://releases.openstack.org/teams/telemetry.html

Developer documentation is available at
https://docs.openstack.org/aetos/latest/

Code Repository
---------------
- Server: https://opendev.org/openstack/aetos

Bug Tracking
------------
- Bugs: https://bugs.launchpad.net/aetos/

IRC
---
IRC Channel: #openstack-telemetry on `OFTC`_.

.. _OFTC: https://oftc.net/
